==> rocketmake-typescript-0.2.0.tgz: package/index.js <==
var process = require('child_process');
var del = require('del');
var fs = require('fs');

function executeCommand(cmd, arguments, cb) {
  var proc = process.spawnSync(cmd, arguments, { stdio: 'inherit' });
  if (proc.status !== 0) {
    cb(new Error("Unable to compile typescript"));
    return;
  }

  cb();
}

function cleanTsdJs(outputFolder) {
  return del.sync(path.join(outputFolder,"**","*.js"));
}

function cleanTsdJsCallback(cb){
  return function (err) {
    if (err) {
      cb(err)
      return;
    }
    cleanTsdJs(outputFolder);
    cb();
  }
}

function splitCommandArgs(cmd){
  return cmd.split(" ")
}

function runTscJs(args, tscLocation, cb){
  if (!tscLocation) {
    tscLocation = "./node_modules/typescript/bin/tsc";
  }
  var argString = args.join(" ");

  if (!fs.existsSync(tscLocation)) {
    cb(new Error("Cannot find tsc at path: " + tscLocation))
    return;
  }
  console.log("Running tsc with arguments: ", argString);
  args.unshift(tscLocation);
  executeCommand("node", args, cb)
}

function compileTs(sourceFolder, tscLocation, cb){
  runTscJs(["-p", sourceFolder], tscLocation, cb);
}

function compileTsd(sourceFolder, outputFolder, tscLocation, cb){
  runTscJs(["-p", sourceFolder, "-d", "--outDir", outputFolder], tscLocation, cleanTsdJsCallback(cb));
}

var tsCompiler = {
  ts: function(sourceFolder, tscLocation) {
    return function (cb) {
      compileTs(sourceFolder, tscLocation, cb);
    }
  },
  dts: function(sourceFolder, outputFolder, tscLocation) {
    return function (cb) {
      compileTsd(sourceFolder, outputFolder, tscLocation, cb);
    }
  },
  tscExec: function(args, tscLocation) {
    return function (cb) {
      runTscJs(args, tscLocation, cb)
    }
  },
  tscCommand: function(cmd, tscLocation) {
    return function (cb) {
      runTscJs(splitCommandArgs(cmd), tscLocation, cb)
    }
  }
}
module.exports = tsCompiler;

==> rocketmake-typescript-0.2.1.tgz: package/index.js <==
var process = require('child_process');
var del = require('del');
var fs = require('fs');

function executeCommand(cmd, arguments, cb) {
  var proc = process.spawnSync(cmd, arguments, { stdio: 'inherit' });
  if (proc.status !== 0) {
    cb(new Error("Unable to compile typescript"));
    return;
  }

  cb();
}

function cleanTsdJs(outputFolder) {
  return del.sync(path.join(outputFolder,"**","*.js"));
}

function cleanTsdJsCallback(outputFolder, cb){
  return function (err) {
    if (err) {
      cb(err)
      return;
    }
    cleanTsdJs(outputFolder);
    cb();
  }
}

function splitCommandArgs(cmd){
  return cmd.split(" ")
}

function runTscJs(args, tscLocation, cb){
  if (!tscLocation) {
    tscLocation = "./node_modules/typescript/bin/tsc";
  }
  var argString = args.join(" ");

  if (!fs.existsSync(tscLocation)) {
    cb(new Error("Cannot find tsc at path: " + tscLocation))
    return;
  }
  console.log("Running tsc with arguments: ", argString);
  args.unshift(tscLocation);
  executeCommand("node", args, cb)
}

function compileTs(sourceFolder, tscLocation, cb){
  runTscJs(["-p", sourceFolder], tscLocation, cb);
}

function compileTsd(sourceFolder, outputFolder, tscLocation, cb){
  runTscJs(["-p", sourceFolder, "-d", "--outDir", outputFolder], tscLocation, cleanTsdJsCallback(outputFolder, cb));
}

var tsCompiler = {
  ts: function(sourceFolder, tscLocation) {
    return function (cb) {
      compileTs(sourceFolder, tscLocation, cb);
    }
  },
  dts: function(sourceFolder, outputFolder, tscLocation) {
    return function (cb) {
      compileTsd(sourceFolder, outputFolder, tscLocation, cb);
    }
  },
  tscExec: function(args, tscLocation) {
    return function (cb) {
      runTscJs(args, tscLocation, cb)
    }
  },
  tscCommand: function(cmd, tscLocation) {
    return function (cb) {
      runTscJs(splitCommandArgs(cmd), tscLocation, cb)
    }
  }
}
module.exports = tsCompiler;
